@@ -6,7 +6,7 @@ boms = {
     "utf-16 (little-endian)": codecs.BOM_UTF16_LE,
 }
 
-def nobom(path):
+def remove_boms(path):
     with open(path, 'rb') as f:
         content = f.read()
     for bom_name, bom in boms.items():
